<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\core;

use PDO;

abstract class AbstractRepository
{
	protected $pdo;

	public function __construct(PDO $pdo)
	{
		$this->pdo = $pdo;
	}

	abstract public function getTableName();

	abstract public function getModelName();

	function all()
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->query("SELECT * FROM `$table`");
		$posts = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $posts;
	}

	function findById($id)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE id = :id");
		$stmt->execute(['id' => $id]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$post = $stmt->fetch(PDO::FETCH_CLASS);

		return $post;
	}

	public function deleteById($id)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"DELETE FROM `$table` WHERE `id` = :id"
		);

		$stmt->execute([
			'id' => $id
		]);
	}
}
?>
