<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\log;

use PDO;

use src\core\abstractRepository;

class logRepository extends abstractRepository
{
	public function getModelName()
	{
		return "src\\log\\logModel";
	}

	public function getTableName()
	{
		return "log";
	}

	public function insert($logData, $level)
	{
 		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"INSERT INTO `$table` (`time`, `logData`, `level`) VALUES (:time, :logData, :level)"
		);

		$stmt->execute([
			'time' => time(),
			'logData' => $logData,
			'level' => $level
		]);

		return $this->pdo->lastInsertId();
	}

	public function getLogs($limit)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` ORDER BY `id` DESC LIMIT :limit");
		$stmt->execute([
			'limit' => $limit
		]);
		$result = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $result;
	}

	public function getLogsByLastId($id)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE id > :id ORDER BY `id` ASC");
		$stmt->execute([
			'id' => $id
		]);
		$result = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $result;
	}

	function getLastId()
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` ORDER BY `id` DESC LIMIT 1");
		$stmt->execute();
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$result = $stmt->fetch(PDO::FETCH_CLASS);

		return $result;
	}
}
?>
