<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\settings;

use src\core\abstractController;
use src\user\loginService;
use src\settings\settingsRepository;

class settingsController extends abstractController
{
	public function __construct(
		loginService $loginService,
		settingsRepository $settingsRepository
	)
	{
		$this->loginService = $loginService;
		$this->settingsRepository = $settingsRepository;
	}

	public function settingsEdit()
	{
		$this->loginService->checkLoggedIn();

		$saved[1] = false;

		$entry = $this->settingsRepository->all();

		if(!empty($_POST["save"]))
		{
			$entry[0]["loginTime"] = $_POST["loginTime"];
			$entry[0]["loginTrys"] = $_POST["loginTrys"];
			$entry[0]["ip"] = $_POST["ip"];
			$entry[0]["maxClientsWait"] = $_POST["maxClientsWait"];
			$entry[0]["wsport"] = $_POST["wsport"];

			if(empty($entry[0]["loginTime"]))
				$errorCode[1] = 'loginTime';
			elseif($entry[0]["loginTime"] > session_cache_expire() or $entry[0]["loginTime"] < 0)
			{
				$errorCode[6] = 'loginTimeSize';
			}

			if(empty($entry[0]["loginTrys"]))
				$errorCode[2] = 'loginTrys';

			if(!isset($entry[0]["ip"]))
				$errorCode[3] = 'ip';

			if(empty($entry[0]["maxClientsWait"]))
				$errorCode[4] = 'maxClientsWait';

			if(empty($entry[0]["wsport"]))
				$errorCode[5] = 'wsport';

			if(!isset($errorCode))
			{
				$this->settingsRepository->update($entry[0]);

				$_SESSION['loginTime'] = $entry[0]["loginTime"];

				$saved[1] = true;
			}
		}

		$this->render("settings/settingsEdit", [
			'entry' => $entry[0],
			'errorCode' => $errorCode,
			'saved' => $saved
		]);
	}
}
