<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\tracker;

use PDO;

use src\core\abstractRepository;


class trackerDataRepository extends abstractRepository
{
	public function getModelName()
	{
		return "src\\tracker\\trackerDataModel";
	}

	public function getTableName()
	{
		return "trackerData";
	}

 	public function findAllBytrackerDeviceId($trackerDeviceId)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE trackerDeviceId = :trackerDeviceId");
		$stmt->execute(['trackerDeviceId' => $trackerDeviceId]);
		$result = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $result;
	}

	public function insertTrackerData($trackerDeviceId, $imei, $time, $status, $latitude, $longitude, $speed, $direction, $event, $voltage, $voltagePercent)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"INSERT INTO `$table` (`trackerDeviceId`, `recivedTime`, `imei`, `time`, `status`, `latitude`, `longitude`, `speed`, `direction`, `event`, `voltage`, `voltagePercent`) VALUES (:trackerDeviceId, :recivedTime, :imei, :time, :status, :latitude, :longitude, :speed, :direction, :event, :voltage, :voltagePercent)"
		);
		$stmt->execute([
			'trackerDeviceId' => $trackerDeviceId,
			'recivedTime' => time(),
			'imei' => $imei,
			'time' => $time,
			'status' => $status,
			'latitude' => $latitude,
			'longitude' => $longitude,
			'speed' => $speed,
			'direction' => $direction,
			'event' => $event,
			'voltage' => $voltage,
			'voltagePercent' => $voltagePercent
		]);

		return $this->pdo->lastInsertId();
	}

	public function getLastTrackingPoint($trackerDeviceId)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		// $stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE trackerDeviceId = :trackerDeviceId ORDER BY `recivedTime` DESC");
		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE trackerDeviceId = :trackerDeviceId ORDER BY `time` DESC");
		$stmt->execute([
			'trackerDeviceId' => $trackerDeviceId
		]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$result = $stmt->fetch(PDO::FETCH_CLASS);

		return $result;
	}

	public function getLastTrackingPointsById($trackerDeviceId, $lastTrackerDataId)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE trackerDeviceId = :trackerDeviceId AND id > :lastTrackerDataId ORDER BY `time` ASC");
		$stmt->execute([
			'trackerDeviceId' => $trackerDeviceId,
			'lastTrackerDataId' => $lastTrackerDataId
		]);
		$result = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $result;
	}

	public function getLastIdByTrackerDeviceId($trackerDeviceId)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE trackerDeviceId = :trackerDeviceId ORDER BY `id` DESC LIMIT 1");
		$stmt->execute([
			'trackerDeviceId' => $trackerDeviceId
		]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$result = $stmt->fetch(PDO::FETCH_CLASS);

		return $result;
	}
}
?>
