<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\tracker;

use PDO;

use src\core\abstractRepository;


class trackerDeviceRepository extends abstractRepository
{
	public function getModelName()
	{
		return "src\\tracker\\trackerDeviceModel";
	}

	public function getTableName()
	{
		return "trackerDevice";
	}

	public function findByImei($imei)
	{
 		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE imei = :imei");
		$stmt->execute(['imei' => $imei]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$result = $stmt->fetch(PDO::FETCH_CLASS);

		return $result;
	}

	public function update(trackerDeviceModel $model)
	{
 		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"UPDATE `$table` SET
				`name` = :name,
				`imei` = :imei,
				`phoneNumber` = :phoneNumber,
				`trackerModelId` = :trackerModelId,
				`function` = :function,
				`status` = :status

				WHERE `id` = :id"
			);

		$stmt->execute([
			'id' => $model->id,
			'name' => $model->name,
			'imei' => $model->imei,
			'phoneNumber' => $model->phoneNumber,
			'trackerModelId' => $model->trackerModelId,
			'function' => $model->function,
			'status' => $model->status
		]);
	}

	public function insert($name, $imei, $phoneNumber, $trackerModelId, $function, $status, $userId)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"INSERT INTO `$table` (
				`name`,
				`imei`,
				`phoneNumber`,
				`trackerModelId`,
				`function`,
				`status`,
				`userId`
			)
			VALUES (
				:name,
				:imei,
				:phoneNumber,
				:trackerModelId,
				:function,
				:status,
				:userId
			)"
		);

		$stmt->execute([
			'name' => $name,
			'imei' => $imei,
			'phoneNumber' => $phoneNumber,
			'trackerModelId' => $trackerModelId,
			'function' => $function,
			'status' => $status,
			'userId' => $userId
		]);

		return $this->pdo->lastInsertId();
	}

	public function getAllTrackerByUserId($userId)
	{
 		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE userId = :userId");
		$stmt->execute([
			'userId' => $userId
		]);
		$result = $stmt->fetchAll(PDO::FETCH_CLASS, $model);

		return $result;
	}
}
?>