<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\user;

use src\core\abstractController;
use src\settings\settingsRepository;
use src\tracker\trackerDataRepository;
use src\tracker\trackerDeviceRepository;

class userController extends abstractController
{
	public function __construct(
		loginService $loginService,
		settingsRepository $settingsRepository,
		trackerDataRepository $trackerDataRepository,
		trackerDeviceRepository $trackerDeviceRepository,
		userRepository $userRepository
	)
	{
		$this->loginService = $loginService;
		$this->settingsRepository = $settingsRepository;
		$this->trackerDataRepository = $trackerDataRepository;
		$this->trackerDeviceRepository = $trackerDeviceRepository;
		$this->userRepository = $userRepository;
	}

	public function dashboard()
	{
		$this->loginService->checkLoggedIn();

		$trackerDeviceId = $_GET["tId"];

		$settings = $this->settingsRepository->all();

		$allTracker = $this->trackerDeviceRepository->getAllTrackerByUserId($_SESSION['loginUID']);

		if(array_search($trackerDeviceId, array_column($allTracker, 'id')) !== false)
		{
			$lastTrackingPoint = $this->trackerDataRepository->getLastTrackingPoint($trackerDeviceId);
		}
		elseif(!empty($trackerDeviceId))
		{
			$this->logout();
		}

		$_SESSION['trackerDeviceId'] = $trackerDeviceId;

		$this->render("user/dashboard", [
			'allTracker' => $allTracker,
			'lastTrackingPoint' => $lastTrackingPoint,
			'settings' => $settings
		]);
	}

	public function users()
	{
		$this->loginService->checkLoggedIn();

 		$delete = $_GET['delete'];

		$all = $this->userRepository->all();

		$this->render("user/users", [
			'all' => $all,
			'delete' => $delete
		]);
	}

	public function userEdit()
	{
		$this->loginService->checkLoggedIn();

 		$id = $_GET['id'];
 		$saved[2] = $_GET['saved2'];

		$entry = $this->userRepository->findById($id);

		$saved[1] = false;

		if(!empty($_POST["delete"]))
		{
			$entry = $this->userRepository->deleteById($id);

			header("Location: ".BASE_URL."/users?delete=true");
			return;
		}

		if(!empty($_POST["save"]))
		{
			$entry["username"] = $_POST["username"];
			$entry["email"] = $_POST["email"];
			$entry["authorization"] = $_POST["authorization"];
			$entry["trylogin"] = $_POST["trylogin"];

			if(empty($entry["username"]))
				$errorCode[1] = 'username';

			if(!empty($_POST["password"]))
				$entry["password"] = password_hash($_POST["password"], PASSWORD_DEFAULT);

			$user = $this->userRepository->findByUsername($entry["username"]);

			if($entry["id"] != $user["id"] and !empty($user))
				$errorCode[3] = 'userexists';

			if(empty($entry["authorization"]))
				$errorCode[4] = 'authorization';

			if(!is_numeric($entry["trylogin"]))
				$errorCode[5] = 'trylogin';

			if(!isset($errorCode))
			{
				$this->userRepository->update($entry);

				$saved[1] = true;
			}
		}

		$entry["lastlogin"] = date('d.m.Y - H:i:s', $entry["lastlogin"]);
		$entry["lastactivity"] = date('d.m.Y - H:i:s', $entry["lastactivity"]);

		$this->render("user/userEdit", [
			'entry' => $entry,
			'errorCode' => $errorCode,
			'saved' => $saved
		]);
	}

	public function userNew()
	{
		$this->loginService->checkLoggedIn();

		if(!empty($_POST["save"]))
		{
			$entry["username"] = $_POST["username"];
			$entry["password"] = $_POST["password"];
			$entry["email"] = $_POST["email"];
			$entry["authorization"] = $_POST["authorization"];
			$entry["trylogin"] = $_POST["trylogin"];

			if(empty($entry["username"]))
				$errorCode[1] = 'username';

			if(empty($entry["password"]))
				$errorCode[2] = 'password';
			else
				$entry["password"] = password_hash($entry["password"], PASSWORD_DEFAULT);

			$user = $this->userRepository->findByUsername($entry["username"]);

			if(!empty($user))
				$errorCode[3] = 'userexists';

			if(empty($entry["authorization"]))
				$errorCode[4] = 'authorization';

			if(!is_numeric($entry["trylogin"]))
				$errorCode[5] = 'trylogin';

			if(empty($entry["trylogin"]))
				$entry["trylogin"] = '0';

			if(!isset($errorCode))
			{
				$id = $this->userRepository->insert(
					$entry["username"],
					$entry["password"],
					$entry["email"],
					$entry["authorization"],
					$entry["trylogin"]
				);

				if($id)
				{
					header("Location: ".BASE_URL."/users/edit?id=".$id."&saved2=true");
					return;
				}
			}
		}

		$this->render("user/userEdit", [
			'entry' => $entry,
			'errorCode' => $errorCode
		]);
	}

	public function login()
	{
		$error = false;

		if(!empty($_POST["username"]) AND !empty($_POST["password"]))
		{
			$username = $_POST["username"];
			$password = $_POST["password"];

			$checkLogin = $this->loginService->loginCheck($username, $password);

			if($checkLogin === true)
			{
				header("Location: ".BASE_URL."/dashboard");
				return;
			}
			else
			{
				$errorCode = $checkLogin;
			}
		}

		$this->render("user/login", [
			'errorCode' => $errorCode
		]);
	}

	public function logout()
	{
		$this->loginService->logout();

		header("Location: ".BASE_URL."/");
		return;
	}
}
?>