<?php
/*
Copyright (C) 2018 Daniel Wirths

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

namespace src\user;

use PDO;

use src\core\abstractRepository;

class userRepository extends abstractRepository
{
	public function getModelName()
	{
		return "src\\user\\userModel";
	}

	public function getTableName()
	{
		return "users";
	}

	public function findByUsername($username)
	{
		$table = $this->getTableName();
		$model = $this->getModelName();

		$stmt = $this->pdo->prepare("SELECT * FROM `$table` WHERE username = :username");
		$stmt->execute(['username' => $username]);
		$stmt->setFetchMode(PDO::FETCH_CLASS, $model);
		$user = $stmt->fetch(PDO::FETCH_CLASS);

		return $user;
	}

	public function update(userModel $model)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"UPDATE `$table` SET `username` = :username, `password` = :password, `email` = :email, `authorization` = :authorization, `lastlogin` = :lastlogin, `trylogin` = :trylogin, `lastactivity` = :lastactivity, `loginbefore` = :loginbefore WHERE `id` = :id"
		);

		$stmt->execute([
			'id' => $model->id,
			'username' => $model->username,
			'password' => $model->password,
			'email' => $model->email,
			'authorization' => $model->authorization,
			'lastlogin' => $model->lastlogin,
			'trylogin' => $model->trylogin,
			'lastactivity' => $model->lastactivity,
			'loginbefore' => $model->loginbefore
		]);
	}

	public function insert($username, $password, $email, $authorization, $trylogin)
	{
		$table = $this->getTableName();

		$stmt = $this->pdo->prepare(
			"INSERT INTO `$table` (`username`, `password`, `email`, `authorization`, `lastlogin`, `trylogin`, `lastactivity`, `loginbefore`, `wsId`) VALUES (:username, :password, :email, :authorization, :lastlogin, :trylogin, :lastactivity, :loginbefore, :wsId)"
		);

		$stmt->execute([
			'username' => $username,
			'password' => $password,
			'email' => $email,
			'authorization' => $authorization,
			'lastlogin' => '0',
			'trylogin' => $trylogin,
			'lastactivity' => '0',
			'loginbefore' => '0'
		]);

		return $this->pdo->lastInsertId();
	}
}
?>
